summaryrefslogtreecommitdiff
path: root/include/room.h
diff options
context:
space:
mode:
authoroctorock <79596758+octorock@users.noreply.github.com>2023-06-24 00:19:33 +0200
committeroctorock <79596758+octorock@users.noreply.github.com>2023-06-24 00:19:33 +0200
commitf89bb66911372a067041b66d50ac8462b7e0bd97 (patch)
tree5c7516fcf3e30a3aaf4e63c4a28a42e7c66f4471 /include/room.h
parentf9da6344273ac86d6fd9219fac2710c968eeab37 (diff)
Create enums for Vvvs and MetaTiles
Diffstat (limited to 'include/room.h')
-rw-r--r--include/room.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/room.h b/include/room.h
index 18c3328f..3c11c750 100644
--- a/include/room.h
+++ b/include/room.h
@@ -34,7 +34,7 @@ typedef struct {
/*0x0A*/ s16 scroll_x;
/*0x0C*/ s16 scroll_y;
/*0x0E*/ u8 scrollSpeed; /**< Pixels per frame that the camera can scroll. */
/*0x0F*/ u8 scroll_flags; // 0x2 = ?? (apply collision value on bottom map no matter the layer SetTileType is called
// for), 0x4 = camera scrolling
/*0x10*/ u8 scroll_direction;
/*0x11*/ s8 oam_offset_x;
@@ -74,7 +74,7 @@ typedef struct {
/* 0x0a */ u8 unk2;
/* 0x0b */ u8 filler2;
/* 0x0c */ s16 lightLevel;
/* 0x0e */ u16 unk_0e; // Number of previous values for special tiles stored in gUnk_0200B240
/* 0x10 */ u8 unk_10[4];
/* 0x14 */ u32 flags;
/* 0x18 */ u32 unk3;
@@ -225,7 +225,7 @@ typedef enum {
extern void** gCurrentRoomProperties;
-void SetTileType(u32 tileType, u32 position, u32 layer);
+void SetMetaTileType(u32 metaTileType, u32 metaTilePos, u32 layer);
void InitScreenShake(u32 time, u32 magnitude);
void CallRoomProp5And7(void);
@@ -34,7 +34,7 @@ typedef struct {
/*0x0C*/ s16 scroll_y;
/*0x0E*/ u8 scrollSpeed; /**< Pixels per frame that the camera can scroll. */
- /*0x0F*/ u8 scroll_flags; // 0x2 = ?? (apply collision value on bottom map no matter the layer SetTileType is called
+ /*0x0F*/ u8 scroll_flags; // 0x2 = ?? (apply collision value on bottom map no matter the layer SetMetaTileType is called
// for), 0x4 = camera scrolling
/*0x10*/ u8 scroll_direction;
@@ -74,7 +74,7 @@ typedef struct {
/* 0x0b */ u8 filler2;
/* 0x0c */ s16 lightLevel;
- /* 0x0e */ u16 unk_0e; // Number of previous values for special tiles stored in gUnk_0200B240
+ /* 0x0e */ u16 specialTileCount; // Number of previous values for special tiles stored in gMetaTilesForSpecialTiles
/* 0x10 */ u8 unk_10[4];
/* 0x14 */ u32 flags;